@@ -1,12 +1,12 @@
 import requests
 
 
-class YXKJapi():
+class UpAndDown():
     def __init__(self) -> None:
         pass
 
     @classmethod
-    def uploadFile(fileType, siteType, algorithm, path):
+    def uploadFile(cls,fileType, siteType, algorithm, path):
         mainURL = "http://172.25.17.120:8080/api/v1/upload/"
         urlParam = f"{fileType}/{siteType}/{algorithm}/"
         files = {
@@ -16,7 +16,7 @@ class YXKJapi():
         r = requests.post(mainURL+urlParam, files=files)
 
     @classmethod
-    def donwloadFile(siteType, algorithm, fileName, savePath):  # 卫星类型、算法、文件名、保存路径
+    def donwloadFile(cls,siteType, algorithm, fileName, savePath):  # 卫星类型、算法、文件名、保存路径
         mainURL = "http://172.25.17.120:8080/api/v1/download/"
         urlParam = f"{siteType}/{algorithm}/{fileName}"
         r = requests.get(mainURL+urlParam)
